package cz.cvut.fel.pr1;

import java.awt.Color;

/**
 *
 * @author jf
 */
public class Point extends Geom implements Printable, Coords {

    private final int x;
    private final int y;
    private int radius;

    /**
     *
     * @param x
     * @param y
     */
    public Point(int x, int y) {
        this(x, y, Color.BLUE, 5);
    }

    /**
     *
     * @param x
     * @param y
     * @param color
     */
    public Point(int x, int y, Color color) {
        this(x, y, color, 5);
    }

    /**
     *
     * @param x
     * @param y
     * @param color
     * @param radius
     */
    public Point(int x, int y, Color color, int radius) {
        super(color);
        this.x = x;
        this.y = y;
        this.radius = radius;
    }

    /**
     *
     * @return
     */
    public int getX() {
        return x;
    }

    /**
     *
     * @return
     */
    public int getY() {
        return y;
    }

    /**
     *
     * @return
     */
    public int getRadius() {
        return radius;
    }

    /**
     *
     * @param radius
     */
    public void setRadius(int radius) {
        this.radius = radius;
    }

    /**
     *
     * @param geom
     * @return
     */
    @Override
    public boolean isEqual(Geom geom) {
        boolean ret = geom == this;
        if (!ret && geom instanceof Point) {
            Point pt = (Point) geom;
            ret = x == pt.x && y == pt.y;
        }
        return ret;
    }

    /**
     *
     * @param geom
     * @return
     */
    @Override
    public boolean isInside(Geom geom) {
        boolean ret = false; // A geom object cannot be inside a point
        return ret;
    }

    @Override
    public void printToCanvas(Canvas canvas) {
        if (canvas == null) {
            return;
        }
        final int w = canvas.getWidth();
        final int h = canvas.getHeight();
        final int r2 = radius * radius;
        for (int i = x - radius; i <= x + radius; ++i) {
            for (int j = y - radius; j <= y + radius; ++j) {
                if (i >= 0 && i < w && j >= 0 && j < h) {
                    final int dx = (x - i);
                    final int dy = (y - j);
                    final int r = dx * dx + dy * dy;
                    if (r < r2) {
                        canvas.setColorAt(i, j, color);
                    }
                }
            }
        }
    }

    @Override
    public String getShapeName() {
        return "Point";
    }

    /**
     *
     * @param x
     * @param y
     * @return
     */
    @Override
    public Coords createCoords(int x, int y) {
        return new Point(x, y);
    }

}
